@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2003-2023 Univention GmbH
+ * Copyright 2003-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -44,7 +44,7 @@ typedef struct {
 	krb5_context context;
 } krb5ContextObject;
 
-PyTypeObject krb5ContextType;
+extern PyTypeObject krb5ContextType;
 
 krb5ContextObject *context_open(PyObject *unused);
 
