@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2003-2023 Univention GmbH
+ * Copyright 2003-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -79,7 +79,7 @@ typedef struct {
 	krb5_keytab keytab;
 } krb5KeytabObject;
 
-PyTypeObject krb5KeytabType;
+extern PyTypeObject krb5KeytabType;
 
 krb5KeytabObject *keytab_open(PyObject *unused, PyObject *args);
 
