@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2003-2023 Univention GmbH
+ * Copyright 2003-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -46,7 +46,7 @@ typedef struct {
 	krb5_principal principal;
 } krb5PrincipalObject;
 
-PyTypeObject krb5PrincipalType;
+extern PyTypeObject krb5PrincipalType;
 
 krb5PrincipalObject *principal_new(PyObject *unused, PyObject *args);
 
