@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2003-2023 Univention GmbH
+ * Copyright 2003-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -46,7 +46,7 @@ typedef struct {
 	krb5_ticket ticket;
 } krb5TicketObject;
 
-PyTypeObject krb5TicketType;
+extern PyTypeObject krb5TicketType;
 
 krb5TicketObject *ticket_new(PyObject *unused, PyObject *args);
 
